@@ -230,8 +230,7 @@ EMPTY_DIR_ENT = "/empty/"
 
 class WeakrefableConnection(sqlite3.Connection):
     def __init__(self, *n, **kw):
-        # we call close() in __del__ which might happen on a different thread
-        kw['check_same_thread'] = False
+        self.funcs = None
         sqlite3.Connection.__init__(self, *n, **kw)
         self.funcs = []
 
@@ -277,8 +276,20 @@ class WeakrefableConnection(sqlite3.Connection):
                 raise Exception("Error while creating function: %r" % (rc,))
 
     def __del__(self):
+        # NB: we should be able to call sqlite3.Connection.close
+        #     even if init was never called but unfortunately that does not
+        #     work, so don't do it.
+        if self.funcs is None:
+            return
         self.close()
 
+def connect_weakrefable(*n, **kw):
+    assert 'factory' not in kw
+    kw['factory'] = WeakrefableConnection
+    # we call close() in __del__ which might happen on a different thread
+    kw['check_same_thread'] = False
+    return sqlite3.connect(*n, **kw)
+
 class _Directory(IterableDirectory):
     def _get_to_iter(self, mutate, fs, path):
         refreshed = True
@@ -772,7 +783,7 @@ class SQLiteFrontFile(PositionIO):
         return conn
 
     def _create_db_conn(self):
-        return sqlite3.connect(self._db_file, factory=WeakrefableConnection, uri=True)
+        return connect_weakrefable(self._db_file, uri=True)
 
     def _get_db_conn(self):
         conn = getattr(self._local, 'conn', None)
@@ -1484,7 +1495,7 @@ class FileSystem(object):
         return str((self._fs.parse_path(path_key) / name).normed())
 
     def _create_db_conn(self):
-        conn = sqlite3.connect(self._db_file, factory=WeakrefableConnection, uri=True)
+        conn = connect_weakrefable(self._db_file, uri=True)
         conn.create_function("attr_merge", 2, wrap_show_exc(attr_merge_sql))
         conn.create_function("norm_join", 2, wrap_show_exc(self._norm_join_sql))
         register_deterministic_function(conn, "file_name_norm", 1, wrap_show_exc(self._fs.file_name_norm))
