@@ -30,6 +30,7 @@ import sys
 import syslog
 import time
 import urllib.request
+import uuid
 
 import appdirs
 
@@ -132,6 +133,7 @@ def on_new_process(proc_args):
             sentry_sdk.init("https://b4b13ebd300849bd92260507a594e618@sentry.io/1293235",
                             release='%s@%s' % (APP_NAME, version),
                             with_locals=False)
+            sentry_sdk.set_user(dict(id=proc_args['sentry_user']))
         except Exception:
             log.warning("Failed to initialize sentry", exc_info=True)
 
@@ -525,6 +527,10 @@ deprecated, this functionality will be removed in the future.
         config['asked_send_error_reports'] = True
         save_config = True
 
+    if config.get("send_error_reports", False) and not isinstance(config.get("sentry_user", None), str):
+        config['sentry_user'] = uuid.uuid4().hex
+        save_config = True
+
     if save_refresh_token and yes_no_input("Do you want \"%s\" to be the default mount point?" % (mount_point,), default_yes=True):
         config['mount_point'] = mount_point
         save_config = True
@@ -540,6 +546,7 @@ deprecated, this functionality will be removed in the future.
             sentry_sdk.init("https://b4b13ebd300849bd92260507a594e618@sentry.io/1293235",
                             release='%s@%s' % (APP_NAME, version),
                             with_locals=False)
+            sentry_sdk.set_user(dict(id=config['sentry_user']))
         except Exception:
             log.warning("Failed to initialize sentry", exc_info=True)
 
@@ -595,6 +602,8 @@ deprecated, this functionality will be removed in the future.
     proc_args['verbose'] = str(args.verbose)
     proc_args['version'] = version
     proc_args['send_error_reports'] = str(int(config.get('send_error_reports', False)))
+    if config.get('send_error_reports', False):
+        proc_args['sentry_user'] = config['sentry_user']
 
     return userspacefs.simple_main(mount_point, display_name,
                                    ('dbxfs.main.create_fs', fs_args),
